@@ -18,6 +18,7 @@ try:
     from cStringIO import StringIO
 except ImportError:
     from io import StringIO
+import locale
 import os
 import shutil
 import tempfile
@@ -64,6 +65,15 @@ class CommandLineTestCase(unittest.TestCase):
             f.write('---\n'
                     'key: value\n')
 
+        # non-ASCII chars
+        os.mkdir(os.path.join(self.wd, 'non-ascii'))
+        with open(os.path.join(self.wd, 'non-ascii', 'utf-8'), 'wb') as f:
+            f.write((u'---\n'
+                     u'- hétérogénéité\n'
+                     u'# 19.99 €\n'
+                     u'- お早う御座います。\n'
+                     u'# الأَبْجَدِيَّة العَرَبِيَّة\n').encode('utf-8'))
+
     def tearDown(self):
         shutil.rmtree(self.wd)
 
@@ -153,6 +163,49 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(out, '')
         self.assertRegexpMatches(err, r'^invalid config: not a dict')
 
+    def test_run_with_config_file(self):
+        with open(os.path.join(self.wd, 'config'), 'w') as f:
+            f.write('rules: {trailing-spaces: disable}')
+
+        with self.assertRaises(SystemExit) as ctx:
+            cli.run(('-c', f.name, os.path.join(self.wd, 'a.yaml')))
+        self.assertEqual(ctx.exception.code, 0)
+
+        with open(os.path.join(self.wd, 'config'), 'w') as f:
+            f.write('rules: {trailing-spaces: enable}')
+
+        with self.assertRaises(SystemExit) as ctx:
+            cli.run(('-c', f.name, os.path.join(self.wd, 'a.yaml')))
+        self.assertEqual(ctx.exception.code, 1)
+
+    def test_run_with_user_global_config_file(self):
+        home = os.path.join(self.wd, 'fake-home')
+        os.mkdir(home)
+        dir = os.path.join(home, '.config')
+        os.mkdir(dir)
+        dir = os.path.join(dir, 'yamllint')
+        os.mkdir(dir)
+        config = os.path.join(dir, 'config')
+
+        temp = os.environ['HOME']
+        os.environ['HOME'] = home
+
+        with open(config, 'w') as f:
+            f.write('rules: {trailing-spaces: disable}')
+
+        with self.assertRaises(SystemExit) as ctx:
+            cli.run((os.path.join(self.wd, 'a.yaml'), ))
+        self.assertEqual(ctx.exception.code, 0)
+
+        with open(config, 'w') as f:
+            f.write('rules: {trailing-spaces: enable}')
+
+        with self.assertRaises(SystemExit) as ctx:
+            cli.run((os.path.join(self.wd, 'a.yaml'), ))
+        self.assertEqual(ctx.exception.code, 1)
+
+        os.environ['HOME'] = temp
+
     def test_run_version(self):
         sys.stdout, sys.stderr = StringIO(), StringIO()
         with self.assertRaises(SystemExit) as ctx:
@@ -218,6 +271,26 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(out, '')
         self.assertEqual(err, '')
 
+    def test_run_non_ascii_file(self):
+        file = os.path.join(self.wd, 'non-ascii', 'utf-8')
+
+        # Make sure the default localization conditions on this "system"
+        # support UTF-8 encoding.
+        loc = locale.getlocale()
+        locale.setlocale(locale.LC_ALL, 'C.UTF-8')
+
+        sys.stdout, sys.stderr = StringIO(), StringIO()
+        with self.assertRaises(SystemExit) as ctx:
+            cli.run(('-f', 'parsable', file))
+
+        locale.setlocale(locale.LC_ALL, loc)
+
+        self.assertEqual(ctx.exception.code, 0)
+
+        out, err = sys.stdout.getvalue(), sys.stderr.getvalue()
+        self.assertEqual(out, '')
+        self.assertEqual(err, '')
+
     def test_run_multiple_files(self):
         items = [os.path.join(self.wd, 'empty.yml'),
                  os.path.join(self.wd, 's')]
