@@ -86,6 +86,13 @@ def run(argv=None):
               'simultaneously.', file=sys.stderr)
         sys.exit(-1)
 
+    # User-global config is supposed to be in ~/.config/yamllint/config
+    if 'XDG_CONFIG_HOME' in os.environ:
+        user_global_config = os.path.join(
+            os.environ['XDG_CONFIG_HOME'], 'yamllint', 'config')
+    else:
+        user_global_config = os.path.expanduser('~/.config/yamllint/config')
+
     try:
         if args.config_data is not None:
             if args.config_data != '' and ':' not in args.config_data:
@@ -95,6 +102,8 @@ def run(argv=None):
             conf = YamlLintConfig(file=args.config_file)
         elif os.path.isfile('.yamllint'):
             conf = YamlLintConfig(file='.yamllint')
+        elif os.path.isfile(user_global_config):
+            conf = YamlLintConfig(file=user_global_config)
         else:
             conf = YamlLintConfig('extends: default')
     except YamlLintConfigError as e:
