@@ -59,7 +59,7 @@ Use this rule to set a limit to lines length.
    the following code snippet would **FAIL**:
    ::
 
-    - this line is waaaaaaaaaaaaaay too long but could be easily splitted...
+    - this line is waaaaaaaaaaaaaay too long but could be easily split...
 
 #. With ``line-length: {max: 60, allow-non-breakable-words: no}``
 
@@ -90,7 +90,7 @@ def check(conf, line):
                 start += 1
 
             if start != line.end:
-                if line.buffer[start] == '#':
+                if line.buffer[start] in ('#', '-'):
                     start += 2
 
                 if line.buffer.find(' ', start, line.end) == -1:
